@@ -15,6 +15,9 @@ import (
 // ErrPlain is the default error that is returned for functions in this package.
 var ErrPlain = errors.New("error")
 
+// Epsilon is used for floating point comparison.
+var Epsilon = 1e-10
+
 ////////////////////////////////////////////////////////////////
 
 func fileline(i int) string {
@@ -51,7 +54,13 @@ func printable(s string) string {
 	s2 := ""
 	for _, r := range s {
 		if !unicode.IsPrint(r) {
-			s2 += fmt.Sprintf("\\x%X", r)
+			if r < 0xFF {
+				s2 += fmt.Sprintf("\\x%02X", r)
+			} else if r < 0xFFFF {
+				s2 += fmt.Sprintf("\\u%04X", r)
+			} else {
+				s2 += fmt.Sprintf("\\U%08X", r)
+			}
 		} else {
 			s2 += string(r)
 		}
@@ -129,7 +138,23 @@ func String(t *testing.T, got, wanted string, msgs ...interface{}) {
 
 func Float(t *testing.T, got, wanted float64, msgs ...interface{}) {
 	t.Helper()
-	if math.IsNaN(wanted) != math.IsNaN(got) || !math.IsNaN(wanted) && math.Abs(got-wanted) > 1e-6 {
+	if math.IsNaN(wanted) != math.IsNaN(got) || !math.IsNaN(wanted) && math.Abs(got-wanted) > Epsilon {
+		t.Fatalf("%s%s: %v != %v", trace(), message(msgs...), color(Red, got), color(Green, wanted))
+	}
+}
+
+func Floats(t *testing.T, got, wanted []float64, msgs ...interface{}) {
+	t.Helper()
+	equal := len(got) == len(wanted)
+	if equal {
+		for i := range got {
+			if math.IsNaN(wanted[i]) != math.IsNaN(got[i]) || !math.IsNaN(wanted[i]) && math.Abs(got[i]-wanted[i]) > Epsilon {
+				equal = false
+				break
+			}
+		}
+	}
+	if !equal {
 		t.Fatalf("%s%s: %v != %v", trace(), message(msgs...), color(Red, got), color(Green, wanted))
 	}
 }
